@@ -20,6 +20,7 @@
  */
 
 #include "scheduler.h"
+#include "helper_p.h"
 #include "akonadi_indexer_agent_debug.h"
 #include "collectionindexingjob.h"
 #include <AkonadiCore/CollectionFetchJob>
@@ -36,9 +37,9 @@ JobFactory::~JobFactory()
 }
 
 CollectionIndexingJob *JobFactory::createCollectionIndexingJob(Index &index, const Akonadi::Collection &col,
-                                                               const QList<Akonadi::Item::Id> &pending,
-                                                               bool fullSync,
-                                                               QObject *parent)
+        const QList<Akonadi::Item::Id> &pending,
+        bool fullSync,
+        QObject *parent)
 {
     CollectionIndexingJob *job = new CollectionIndexingJob(index, col, pending, parent);
     job->setFullSync(fullSync);
@@ -50,7 +51,7 @@ Scheduler::Scheduler(Index &index, const KSharedConfigPtr &config,
     :   QObject(parent),
         m_config(config),
         m_index(index),
-        m_currentJob(0),
+        m_currentJob(nullptr),
         m_jobFactory(jobFactory),
         m_busyTimeout(5000)
 {
@@ -72,7 +73,7 @@ Scheduler::Scheduler(Index &index, const KSharedConfigPtr &config,
     }
 
     qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Dirty collections " << m_dirtyCollections;
-    Q_FOREACH (Akonadi::Collection::Id col, m_dirtyCollections) {
+    for (Akonadi::Collection::Id col : qAsConst(m_dirtyCollections)) {
         scheduleCollection(Akonadi::Collection(col), true);
     }
 
@@ -175,7 +176,8 @@ void Scheduler::scheduleCompleteSync()
 void Scheduler::slotRootCollectionsFetched(KJob *kjob)
 {
     Akonadi::CollectionFetchJob *cjob = static_cast<Akonadi::CollectionFetchJob *>(kjob);
-    Q_FOREACH (const Akonadi::Collection &c, cjob->collections()) {
+    const Akonadi::Collection::List lstCols = cjob->collections();
+    for (const Akonadi::Collection &c : lstCols) {
         //For skipping search collections
         if (c.isVirtual()) {
             continue;
@@ -184,7 +186,7 @@ void Scheduler::slotRootCollectionsFetched(KJob *kjob)
             continue;
         }
         if (c.hasAttribute<Akonadi::IndexPolicyAttribute>() &&
-            !c.attribute<Akonadi::IndexPolicyAttribute>()->indexingEnabled()) {
+                !c.attribute<Akonadi::IndexPolicyAttribute>()->indexingEnabled()) {
             continue;
         }
         scheduleCollection(c, true);
@@ -200,7 +202,8 @@ void Scheduler::slotRootCollectionsFetched(KJob *kjob)
 void Scheduler::slotCollectionsToIndexFetched(KJob *kjob)
 {
     Akonadi::CollectionFetchJob *cjob = static_cast<Akonadi::CollectionFetchJob *>(kjob);
-    Q_FOREACH (const Akonadi::Collection &c, cjob->collections()) {
+    const Akonadi::Collection::List lstCols = cjob->collections();
+    for (const Akonadi::Collection &c : lstCols) {
         //For skipping search collections
         if (c.isVirtual()) {
             continue;
@@ -209,7 +212,7 @@ void Scheduler::slotCollectionsToIndexFetched(KJob *kjob)
             continue;
         }
         if (c.hasAttribute<Akonadi::IndexPolicyAttribute>() &&
-            !c.attribute<Akonadi::IndexPolicyAttribute>()->indexingEnabled()) {
+                !c.attribute<Akonadi::IndexPolicyAttribute>()->indexingEnabled()) {
             continue;
         }
         m_index.index(c);
@@ -221,7 +224,7 @@ void Scheduler::abort()
     if (m_currentJob) {
         m_currentJob->kill(KJob::Quietly);
     }
-    m_currentJob = 0;
+    m_currentJob = nullptr;
     collectDirtyCollections();
     m_collectionQueue.clear();
     status(Akonadi::AgentBase::Idle, i18n("Ready"));
@@ -270,6 +273,6 @@ void Scheduler::slotIndexingFinished(KJob *job)
         m_dirtyCollections.remove(collectionId);
         status(Akonadi::AgentBase::Idle, i18n("Collection \"%1\" indexed", collectionId));
     }
-    m_currentJob = 0;
+    m_currentJob = nullptr;
     m_processTimer.start();
 }
