@@ -39,29 +39,30 @@ using namespace Akonadi::Search;
 
 static Term::Operation mapRelation(Akonadi::SearchTerm::Relation relation)
 {
-    if (relation == Akonadi::SearchTerm::RelAnd){
+    if (relation == Akonadi::SearchTerm::RelAnd) {
         return Term::And;
     }
     return Term::Or;
 }
 
-static Term::Comparator mapComparator(Akonadi::SearchTerm::Condition comparator) {
-    if (comparator == Akonadi::SearchTerm::CondContains){
+static Term::Comparator mapComparator(Akonadi::SearchTerm::Condition comparator)
+{
+    if (comparator == Akonadi::SearchTerm::CondContains) {
         return Term::Contains;
     }
-    if (comparator == Akonadi::SearchTerm::CondGreaterOrEqual){
+    if (comparator == Akonadi::SearchTerm::CondGreaterOrEqual) {
         return Term::GreaterEqual;
     }
-    if (comparator == Akonadi::SearchTerm::CondGreaterThan){
+    if (comparator == Akonadi::SearchTerm::CondGreaterThan) {
         return Term::Greater;
     }
-    if (comparator == Akonadi::SearchTerm::CondEqual){
+    if (comparator == Akonadi::SearchTerm::CondEqual) {
         return Term::Equal;
     }
-    if (comparator == Akonadi::SearchTerm::CondLessOrEqual){
+    if (comparator == Akonadi::SearchTerm::CondLessOrEqual) {
         return Term::LessEqual;
     }
-    if (comparator == Akonadi::SearchTerm::CondLessThan){
+    if (comparator == Akonadi::SearchTerm::CondLessThan) {
         return Term::Less;
     }
     return Term::Auto;
@@ -198,7 +199,7 @@ Term recursiveCalendarTermMapping(const Akonadi::SearchTerm &term)
 {
     if (!term.subTerms().isEmpty()) {
         Term t(mapRelation(term.relation()));
-        Q_FOREACH (const Akonadi::SearchTerm &subterm, term.subTerms()) {
+        for (const Akonadi::SearchTerm &subterm : term.subTerms()) {
             const Term newTerm = recursiveCalendarTermMapping(subterm);
             if (newTerm.isValid()) {
                 t.addSubTerm(newTerm);
@@ -231,7 +232,7 @@ Term recursiveNoteTermMapping(const Akonadi::SearchTerm &term)
 {
     if (!term.subTerms().isEmpty()) {
         Term t(mapRelation(term.relation()));
-        Q_FOREACH (const Akonadi::SearchTerm &subterm, term.subTerms()) {
+        for (const Akonadi::SearchTerm &subterm : term.subTerms()) {
             const Term newTerm = recursiveNoteTermMapping(subterm);
             if (newTerm.isValid()) {
                 t.addSubTerm(newTerm);
@@ -257,7 +258,7 @@ Term recursiveContactTermMapping(const Akonadi::SearchTerm &term)
 {
     if (!term.subTerms().isEmpty()) {
         Term t(mapRelation(term.relation()));
-        Q_FOREACH (const Akonadi::SearchTerm &subterm, term.subTerms()) {
+        for (const Akonadi::SearchTerm &subterm : term.subTerms()) {
             const Term newTerm = recursiveContactTermMapping(subterm);
             if (newTerm.isValid()) {
                 t.addSubTerm(newTerm);
@@ -284,7 +285,7 @@ Term recursiveContactTermMapping(const Akonadi::SearchTerm &term)
     return Term();
 }
 
-QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QList<qint64> &collections, const QStringList &mimeTypes)
+QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QVector<qint64> &collections, const QStringList &mimeTypes)
 {
     const Akonadi::SearchQuery searchQuery = Akonadi::SearchQuery::fromJSON(akonadiQuery.toLatin1());
     if (searchQuery.isNull()) {
@@ -332,7 +333,7 @@ QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QList<qint6
     if (!collections.isEmpty()) {
         Term parentTerm(Term::And);
         Term collectionTerm(Term::Or);
-        Q_FOREACH (const qint64 col, collections) {
+        for (const qint64 col : collections) {
             collectionTerm.addSubTerm(Term(QStringLiteral("collection"), QString::number(col), Term::Equal));
         }
         parentTerm.addSubTerm(collectionTerm);
