@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2014 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -35,10 +35,10 @@ class CalendarSearchStore : public PIMSearchStore
     Q_OBJECT
     Q_INTERFACES(Akonadi::Search::SearchStore)
 #ifndef AKONADI_SEARCH_NO_PLUGINS
-    Q_PLUGIN_METADATA(IID "org.kde.Akonadi.Search.SearchStore" FILE "calendarsearchstore.json") 
+    Q_PLUGIN_METADATA(IID "org.kde.Akonadi.Search.SearchStore" FILE "calendarsearchstore.json")
 #endif
 public:
-    explicit CalendarSearchStore(QObject *parent = Q_NULLPTR);
+    explicit CalendarSearchStore(QObject *parent = nullptr);
 
     QStringList types() Q_DECL_OVERRIDE;
 };
