@@ -38,7 +38,7 @@ XapianSearchStore::XapianSearchStore(QObject *parent)
     : SearchStore(parent)
     , m_mutex(QMutex::Recursive)
     , m_nextId(1)
-    , m_db(0)
+    , m_db(nullptr)
 {
 }
 
@@ -52,7 +52,7 @@ void XapianSearchStore::setDbPath(const QString &path)
     m_dbPath = path;
 
     delete m_db;
-    m_db = 0;
+    m_db = nullptr;
 
     try {
         m_db = new Xapian::Database(m_dbPath.toUtf8().constData());
@@ -78,7 +78,7 @@ Xapian::Query XapianSearchStore::toXapianQuery(Xapian::Query::op op, const QList
     QVector<Xapian::Query> queries;
     queries.reserve(terms.size());
 
-    Q_FOREACH (const Term &term, terms) {
+    for (const Term &term : terms) {
         Xapian::Query q = toXapianQuery(term);
         queries << q;
     }
